function v=compute_ekman_surge_bet(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes ekman_surge_bet
% Script automatically generated by fit_ekman_surge_bet.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.74985
% RMSE  = 0.90832
% MEAN  = 0.70141
% RANGE = -3.792 - 4.1414

beta( 1 )= 2.2633e+00 ;
beta( 2 )= 5.1297e+01 ;
beta( 3 )= -6.2417e-02 ;
beta( 4 )= -3.4552e-02 ;
beta( 5 )= -2.3471e+00 ;
beta( 6 )= 7.9463e+00 ;
beta( 7 )= -2.8940e+01 ;
beta( 8 )= 0.0000e+00 ;
beta( 9 )= 1.3905e+01 ;
beta( 10 )= 6.9305e+01 ;
beta( 11 )= -5.6202e+01 ;
beta( 12 )= -2.0596e-02 ;
beta( 13 )= 5.4508e-03 ;
beta( 14 )= 7.8408e-03 ;

v=beta(1) + beta(2)*a + beta(4)*lat + beta(5)*cos((phi-beta(7))*pi/180) + beta(3)*w.*exp(-vt.*cos((phi)*pi/180)/beta(6)) + beta(9)*(exp(-vmax/beta(10))) + beta(11)*n + beta(12)*rmax + beta(13)*r35 + beta(14).*phi_in;
